==> accounts_management-0.1.6.gem: app/controllers/accounts_management/ledgers/accounts_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::AccountsController < AccountsManagementController
    # GET /ledgers/accounts
    # GET /ledgers/accounts.json
    def index
      @ledgers_accounts = Ledgers::Account.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @ledgers_accounts }
      end
    end

    # GET /ledgers/accounts/1
    # GET /ledgers/accounts/1.json
    def show
      @ledgers_account = Ledgers::Account.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @ledgers_account }
      end
    end

    # GET /ledgers/accounts/new
    # GET /ledgers/accounts/new.json
    def new
      @ledgers_account = Ledgers::Account.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @ledgers_account }
      end
    end

    # GET /ledgers/accounts/1/edit
    def edit
      @ledgers_account = Ledgers::Account.find(params[:id])
    end

    # POST /ledgers/accounts
    # POST /ledgers/accounts.json
    def create
      @ledgers_account = Ledgers::Account.new(params[:ledgers_account])

      respond_to do |format|
        if @ledgers_account.save
          format.html { redirect_to @ledgers_account, :notice => 'Account was successfully created.' }
          format.json { render :json => @ledgers_account, :status => :created, :location => @ledgers_account }
        else
          format.html { render :action => "new" }
          format.json { render :json => @ledgers_account.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/accounts/1
    # PUT /ledgers/accounts/1.json
    def update
      @ledgers_account = Ledgers::Account.find(params[:id])

      respond_to do |format|
        if @ledgers_account.update_attributes(params[:ledgers_account])
          format.html { redirect_to @ledgers_account, :notice => 'Account was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @ledgers_account.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/accounts/1
    # DELETE /ledgers/accounts/1.json
    def destroy
      @ledgers_account = Ledgers::Account.find(params[:id])
      @ledgers_account.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_accounts_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/ledgers/accounts_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::AccountsController < AccountsManagementController
    # GET /ledgers/accounts
    # GET /ledgers/accounts.json
    def index
      @ledgers_accounts = Ledgers::Account.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @ledgers_accounts }
      end
    end

    # GET /ledgers/accounts/1
    # GET /ledgers/accounts/1.json
    def show
      @ledgers_account = Ledgers::Account.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @ledgers_account }
      end
    end

    # GET /ledgers/accounts/new
    # GET /ledgers/accounts/new.json
    def new
      @ledgers_account = Ledgers::Account.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @ledgers_account }
      end
    end

    # GET /ledgers/accounts/1/edit
    def edit
      @ledgers_account = Ledgers::Account.find(params[:id])
    end

    # POST /ledgers/accounts
    # POST /ledgers/accounts.json
    def create
      @ledgers_account = Ledgers::Account.new(params[:ledgers_account])

      respond_to do |format|
        if @ledgers_account.save
          format.html { redirect_to @ledgers_account, notice: 'Account was successfully created.' }
          format.json { render json: @ledgers_account, status: :created, location: @ledgers_account }
        else
          format.html { render action: "new" }
          format.json { render json: @ledgers_account.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/accounts/1
    # PUT /ledgers/accounts/1.json
    def update
      @ledgers_account = Ledgers::Account.find(params[:id])

      respond_to do |format|
        if @ledgers_account.update_attributes(params[:ledgers_account])
          format.html { redirect_to @ledgers_account, notice: 'Account was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @ledgers_account.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/accounts/1
    # DELETE /ledgers/accounts/1.json
    def destroy
      @ledgers_account = Ledgers::Account.find(params[:id])
      @ledgers_account.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_accounts_url }
        format.json { head :no_content }
      end
    end
  end
end
